==> weld-osgi-bundle-3.0.5.Final-sources.jar: org/jboss/weld/util/SecurityActions.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2016, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.weld.util;

import java.lang.reflect.Constructor;
import java.security.AccessController;
import java.security.PrivilegedActionException;

import org.jboss.weld.security.GetDeclaredConstructorAction;

/**
 *
 * @author Martin Kouba
 */
final class SecurityActions {

    private SecurityActions() {
    }

    static Constructor<?> getDeclaredConstructor(Class<?> javaClass, Class<?>... parameterTypes) throws NoSuchMethodException, PrivilegedActionException {
        if (System.getSecurityManager() != null) {
            return AccessController.doPrivileged(GetDeclaredConstructorAction.of(javaClass));
        } else {
            return javaClass.getDeclaredConstructor(parameterTypes);
        }
    }

}

==> weld-osgi-bundle-5.1.4.Final-sources.jar: org/jboss/weld/util/SecurityActions.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2016, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.weld.util;

import java.lang.reflect.Constructor;
import java.security.AccessController;
import java.security.PrivilegedActionException;

import org.jboss.weld.security.GetDeclaredConstructorAction;

/**
 *
 * @author Martin Kouba
 */
final class SecurityActions {

    private SecurityActions() {
    }

    static Constructor<?> getDeclaredConstructor(Class<?> javaClass, Class<?>... parameterTypes)
            throws NoSuchMethodException, PrivilegedActionException {
        if (System.getSecurityManager() != null) {
            return AccessController.doPrivileged(GetDeclaredConstructorAction.of(javaClass));
        } else {
            return javaClass.getDeclaredConstructor(parameterTypes);
        }
    }

}
